﻿using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace TrendlineSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        SfChart chart = new SfChart();
        public MainWindow()
        {
            InitializeComponent();
            CreateChart();
            DisplayTrendline();
        }

        private void CreateChart()
        {
            chart.Margin = new Thickness(10, 10, 10, 10);
            ViewModel view = new ViewModel();
            chart.PrimaryAxis = new NumericalAxis();
            chart.SecondaryAxis = new NumericalAxis() { Minimum = 0, Maximum = 100 };

            FastLineSeriesWithHighlight series1 = new FastLineSeriesWithHighlight() { XBindingPath = "XData", YBindingPath = "YData", ItemsSource = view.Datas, Interior = Brushes.Blue };
            FastLineSeriesWithHighlight series2 = new FastLineSeriesWithHighlight() { XBindingPath = "XData", YBindingPath = "YData", ItemsSource = view.Items, Interior = Brushes.Brown };
            FastLineSeriesWithHighlight series3 = new FastLineSeriesWithHighlight() { XBindingPath = "XData", YBindingPath = "YData", ItemsSource = view.Datas1, Interior = Brushes.Green };

            chart.Series.Add(series1);
            chart.Series.Add(series2);
            chart.Series.Add(series3);
            grid.Children.Add(chart);
        }


        private void DisplayTrendline()
        {
            for (int i = 0; i < chart.Series.Count(); i++)
            {
                Trendline trendline = new Trendline();
                trendline.Stroke = (chart.Series[i] as FastLineSeriesWithHighlight)._Segments[0].Interior;
                (chart.Series[i] as FastLineSeriesWithHighlight).Trendlines = new ChartTrendLineCollection();
                (chart.Series[i] as FastLineSeriesWithHighlight).Trendlines.Add(trendline);
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            DisplayTrendline();
        }
    }

    public class Model
    {
        public double XData { get; set; }

        public double YData { get; set; }
    }

    public class ViewModel
    {
        public ViewModel()
        {
            Random rand = new Random();
            this.Datas = new ObservableCollection<Model>();
            Items = new ObservableCollection<Model>();
            Datas1 = new ObservableCollection<Model>();

            for (int i = 1; i <= 50; i++)
            {
                Datas.Add(new Model() { XData = i, YData = rand.Next(0, 30) });
                Items.Add(new Model() { XData = i, YData = rand.Next(30, 60) });
                Datas1.Add(new Model() { XData = i, YData = rand.Next(60, 90) });
            }

        }

        public ObservableCollection<Model> Datas { get; set; }

        public ObservableCollection<Model> Items { get; set; }

        public ObservableCollection<Model> Datas1 { get; set; }
    }


    public class FastLineSeriesWithHighlight : FastLineSeries
    {
        public ObservableCollection<ChartSegment> _Segments
        {
            get
            {
                return base.Segments;
            }
            set
            {
                _Segments = value;
            }
        }

        protected override void OnMouseMove(MouseEventArgs e)
        {
            FrameworkElement element = e.OriginalSource as FrameworkElement;
            if (element != null && element.Tag != null)
            {
                ChartSegment segment = element.Tag as ChartSegment;
                foreach (var _segment in _Segments)
                {
                    if (_segment != segment)
                    {
                        SolidColorBrush clone = (_segment.Interior as SolidColorBrush).Clone();
                        clone.Opacity = 1.0;
                        _segment.Interior = clone;

                        if (((FastLineSeriesWithHighlight)_segment.Series).Trendlines.Count() > 0)
                        {
                            Trendline trendline = ((FastLineSeriesWithHighlight)_segment.Series).Trendlines[0];
                            trendline.Stroke = clone;
                        }
                    }
                }
            }
            base.OnMouseMove(e);

        }

        protected override void OnMouseLeave(MouseEventArgs e)
        {
            foreach (var segment in _Segments)
            {
                SolidColorBrush clone = (segment.Interior as SolidColorBrush).Clone();
                clone.Opacity = 0.2;
                segment.Interior = clone;

                if (((FastLineSeriesWithHighlight)segment.Series).Trendlines.Count() > 0)
                {
                    Trendline trendline = ((FastLineSeriesWithHighlight)segment.Series).Trendlines[0];
                    trendline.Stroke = clone;
                }
            }
            base.OnMouseLeave(e);
        }
    }



}
